@@ -278,24 +278,137 @@ package Object::Simple;
 
 =head1 NAME
 
-Object::Simple - Provide new() and accessor creating methods
-
-=head1 STATE
-
-This module is now stable. I will not change APIs and implemetations.
-I will only fix bug if it is found.
-Version 3.0601 implementation is keeped for ever.
+Object::Simple - generate accessor with default, and provide constructor
 
 =head1 VERSION
 
-Version 3.0606
+Version 3.0607
 
 =cut
 
-our $VERSION = '3.0606';
+our $VERSION = '3.0607';
 
 =head1 SYNOPSIS
 
+    package YourClass;
+    
+    use base 'Object::Simple';
+    
+    # Generate accessor
+    __PACKAGE__->attr('x');
+    
+    # Generate accessor with default (scalar)
+    __PACKAGE__->attr(x => 0);
+    
+    # Generate accessor with default (reference or instance)
+    __PACKAGE__->attr(x => sub { [] });
+    __PACKAGE__->attr(x => sub { {} });
+    __PACKAGE__->attr(x => sub { SomeClass->new });
+    
+    # Generate accessors at once
+    __PACKAGE__->attr([qw/x y z/]);
+    
+    # Generate accessors with default at once
+    __PACKAGE__->attr([qw/x y z/] => 0);
+    
+    # Generate class accessor
+    __PACKAGE__->class_attr('x');
+    __PACKAGE__->class_attr(x => 0);
+    
+    # Generate inheritable class accessor
+    __PACKAGE__->class_attr('x', default => 0, inherit => 'scalar_copy');
+    __PACKAGE__->class_attr('x', default => sub { [] }, inherit => 'array_copy');
+    __PACKAGE__->class_attr('x', default => sub { {} }, inherit => 'hash_copy');
+    
+    __PACKAGE__->class_attr(
+      'x', default => sub { SomeClass->new }, inherit => sub { shift->clone });
+    
+    # Generate dual accessor, which work as normal accessor or class accessor
+    __PACKAGE__->dual_attr('x');
+    __PACKAGE__->dual_attr(x => 0);
+    
+    # Generate inheritable dual accessor
+    __PACKAGE__->dual_attr('x', default => 0, inherit => 'scalar_copy');
+    __PACKAGE__->dual_attr('x', default => sub { [] }, inherit => 'array_copy');
+    __PACKAGE__->dual_attr('x', default => sub { {} }, inherit => 'hash_copy');
+    
+    __PACKAGE__->dual_attr(
+      'x', default => sub { SomeClass->new }, inherit => sub { shift->clone });
+    
+    package main;
+    
+    # Constructor new()
+    my $obj = YourClass->new;
+    my $obj = YourClass->new(x => 1, y => 2);
+    my $obj = YourClass->new({x => 1, y => 2});
+    
+    # Set attribute
+    $obj->x(1);
+    
+    # Setter method chain is available
+    $obj->x(1)->y(2);
+    
+    # Get attribute
+    my $x = $obj->x;
+
+=head1 DESCRIPTION
+
+=head2 introduction
+
+L<Object::Simple> is the generator of accessor.
+If you want to create a class, you must write many accessors by yourself,
+so you will be tired of writing accesors.
+
+L<Object::Simple> help you to create accessor.
+You can call attr() method to create accessor
+from subclass of L<Object::Simple>
+    
+    package YourClass;
+    
+    use base 'Object::Simple';
+
+    # Generate accessor
+    __PACKAGE__->attr('x');
+
+L<Object::Simple> also provide constructor new().
+new() can receive hash or hash reference.
+
+    # Constructor new()
+    my $obj = YourClass->new(x => 1, y => 2);
+    my $obj = YourClass->new({x => 1, y => 2});
+
+This instance can call x() to set and get attribute.
+
+    # Set attribute
+    $obj->x(1);
+    
+    # Get attribute
+    my $x = $obj->x;
+    
+Default value for accessor can be specified.
+If x() is called at first, the default value is set to the attribute.
+
+    # Generate accessor with default (scalar)
+    __PACKAGE__->attr(x => 0);
+
+If you specifiy a reference or instance as default value,
+it must be return value of sub reference.
+This is requirement not to share the value with more than one instance.
+
+    # Generate accessor with default (reference or instance)
+    __PACKAGE__->attr(x => sub { [] });
+    __PACKAGE__->attr(x => sub { {} });
+    __PACKAGE__->attr(x => sub { SomeClass->new });
+
+=head2 examples
+
+I wrote Point and Point3D class.
+Point has two accessor x() and y(), and method clear().
+
+Point3D is subclass of Point.
+Point3D has three accessor x(), y(), z(), and method clear()
+which is overridden.
+
     package Point;
     
     use strict;
@@ -327,65 +440,13 @@ our $VERSION = '3.0606';
         $self->SUPER::clear();
         $self->z(0);
     }
-    
-    package main;
-    
-    use strict;
-    use warnings;
-    
-    my $point = Point3D->new(x => 4, y => 6, z => 5);
-    
-    $point->x(1);
-    $point->y(2);
-    $point->z(5);
-    
-    my $x = $point->x;
-    my $y = $point->y;
-    my $z = $point->z;
-    
-    $point->clear;
 
-=head1 FEATURES
+=head2 how to override new()
 
-This module has the folloing features. 
+You can override new() to initialize the instance or arrange arguments.
+To call super class new(), you can use SUPER pseudo-class.
 
-=over 4
-
-=item 1. new() and accessor creating methods is prepared.
-
-=item 2. Default value is available.
-
-=item 3. Object Oriented interface and pure perl implemetation.
-
-=item 4. Memory saving implementation and fast Compiling.
-
-=item 5. Debugging is easy.
-
-=back
-
-You can think L<Object::Simple> is L<Class::Accessor::Fast> + "default value definition" + "useful new()"
-
-This module's API is compatible of L<Mojo::Base>.
-If you like L<Mojo::Base>, this module is good choice.
-
-=head1 METHODS
-
-=head2 new
-
-A subclass of Object::Simple can call "new", and create a instance.
-"new" receive hash or hash reference.
-
-    package Point;
-    use base 'Object::Simple';
-    
-    package main;
-    my $book = Point->new;
-    my $book = Point->new(x => 1, y => 2);
-    my $book = Point->new({x => 1, y => 2});
-
-"new" can be overrided to initialize the instance or arrange arguments.
-
-Instance initialization
+Initialize instance:
 
     sub new {
         my $self = shift->SUPER::new(@_);
@@ -395,7 +456,7 @@ Instance initialization
         return $self;
     }
 
-Arguments arranging
+Arrange arguments:
     
     sub new {
         my $self = shift;
@@ -405,186 +466,148 @@ Arguments arranging
         return $self;
     }
 
+=head2 import accessor generating methods
+
+You can only import accessor generating methods if you need.
+
+    package YourClass;
+    
+    use Object::Simple qw/attr class_attr dual_attr/;
+    
+    __PACKAGE__->attr('x');
+
+=head2 implementation
+
+attr(), class_attr(), and dual_attr() is implemented by closure, not eval,
+so memory efficiency is very good.
+and the performance of compiling is very fast.
+
+And accessor is optimized not to damage the performance.
+
+L<Object::Simple> pay attention to usability.
+If wrong number arguments is passed to new() or accessor,
+exception is thrown.
+    
+    # Exception!
+    my $obj = YourClass->new(1); 
+    
+    # Exception!
+    $obj->x(a => 1);
+
+=head2 history
+
+L<Class::Accessor::Fast> is very useful.
+so I wanted to add new new features to that.
+But when I looked at L<Mojo::Base>, I realized that it is not necessarily
+to have many features to do Object Oriented Programing.
+
+So I decided that L<Object::Simple> has compatible of L<Mojo::Base>.
+L<Mojo::Base> is minimal but enough
+to do Object Oriented Programing.
+
+=head1 METHODS
+
+=head2 new
+
+Create instance. the subclass of L<Object::Simple> inherit new() method.
+"new" receive hash or hash reference.
+
+    package YourClass;
+    
+    use base 'Object::Simple';
+
+    my $obj = YourClass->new;
+    my $obj = YourClass->new(x => 1, y => 2);
+    my $obj = YourClass->new({x => 1, y => 2});
+
 =head2 attr
 
-Create accessor.
+Generate accessor.
     
-    __PACKAGE__->attr('name');
-    __PACKAGE__->attr([qw/name1 name2 name3/]);
+    __PACKAGE__->attr('x');
+    __PACKAGE__->attr([qw/x y z/]);
 
-A default value can be specified.
-If dfault value is reference or object, You must wrap the value with sub { }.
+You can specify default value for accessor.
 
-    __PACKAGE__->attr(name => 'foo');
-    __PACKAGE__->attr(name => sub { ... });
-    __PACKAGE__->attr([qw/name1 name2/] => 'foo');
-    __PACKAGE__->attr([qw/name1 name2/] => sub { ... });
+    __PACKAGE__->attr(x => 0);
+    __PACKAGE__->attr([qw/x y z/] => 0);
 
-Accessor is chained.
+If you specifiy a reference or instance as default value,
+it must be return value of sub reference.
+This is requirement not to share the value with more than one instance.
 
-    $point->x(3)->y(4);
-    
-The folloing is a sample.
+    __PACKAGE__->attr(x => sub { [] });
+    __PACKAGE__->attr(x => sub { {} });
+    __PACKAGE__->attr(x => sub { SomeClass->new });
 
-    package Car;
-    use base 'Object::Simple';
-    
-    __PACKAGE__->attr(maintainer => sub { ['Ken', 'Beck'] });
-    __PACKAGE__->attr(handle => sub { Car::Handle->new });
-    __PACKAGE__->attr([qw/speed passenger/] => 0);
+Setter is chained.
+
+    $obj->x(3)->y(4);
     
 =head2 class_attr
 
-Create accessor for class attribute.
+Generate class accessor.
 
-    __PACKAGE__->class_attr('name');
-    __PACKAGE__->class_attr([qw/name1 name2 name3/]);
-    __PACKAGE__->class_attr(name => 'foo');
-    __PACKAGE__->class_attr(name => sub { ... });
+    __PACKAGE__->class_attr('x');
+    __PACKAGE__->class_attr(x => 0);
+    __PACKAGE__->class_attr([qw/x y z/]);
 
-This accessor is called from class.
+Class accessor is called by class, not instance.
 
-    Book->title('BBB');
+    YourClass->x(5);
 
-Class attribute is saved to $CLASS_ATTRS. This is class variable.
-If you want to delete or check existence of a class attribute,
+The value is saved to $CLASS_ATTRS in that class.
+
+If you want to delete the value or check the existence it,
 "delete" or "exists" function is available.
 
-    delete $SomeClass::CLASS_ATTRS->{name};
-    exists $SomeCLass::CLASS_ATTRS->{name};
+    delete $YourClass::CLASS_ATTRS->{x};
+    exists $YourClass::CLASS_ATTRS->{x};
 
-If the class is a subclass, the class attribute is saved to $CLASS_ATTRS of subclass .
-See the following sample.
+If you call class accessor from subclass,
+the value is saved to $CLASS_ATTRS in the subclass.
+    
+    # The value is saved to $YourSubClass::CLASS_ATTRS
+    YourSubClass->x(6); 
 
-    package Book;
-    use base 'Object::Simple';
-    
-    __PACKAGE__->class_attr('title');
-    
-    package Magazine;
-    use base 'Book';
-    
-    package main;
-    
-    Book->title('Beautiful days');
-    Magazine->title('Good days');
+Class accessor can inherit the value of class variable in super class.
 
-If Book->title('Beautiful days') is called,
-the value is saved to $Book::CLASS_ATTRS->{title}.
-If Magazine->title('Good days') is called,
-the value is saved to $Magazine::CLASS_ATTRS->{title}.
+    __PACKAGE__->class_attr('x', default => 0, inherit => 'scalar_copy');
+    __PACKAGE__->class_attr('x', default => sub { [] }, inherit => 'array_copy');
+    __PACKAGE__->class_attr('x', default => sub { {} }, inherit => 'hash_copy');
 
 =head2 dual_attr
 
-Create accessor for a attribute and class attribute.
+Generate dual accessor, which work as normal accessor or class accessor.
 
-    __PACKAGE__->dual_attr('name');
-    __PACKAGE__->dual_attr([qw/name1 name2 name3/]);
-    __PACKAGE__->dual_attr(name => 'foo');
-    __PACKAGE__->dual_attr(name => sub { ... });
+    __PACKAGE__->class_attr('x');
+    __PACKAGE__->class_attr(x => 0);
+    __PACKAGE__->class_attr([qw/x y z/]);
 
-If the accessor is called from a package, the value is saved to $CLASS_ATTRS.
-If the accessor is called from a instance, the value is saved to the instance.
+Accessor is called both by instance and class.
+If called by instance, the accessor work as normal accessor.
+If called by class, the accessor work as class accessor.
 
-    Book->title('Beautiful days');
+    $obj->x(5)
+    YourClass->x(5);
+
+Dual accessor can inherit the value of class variable if called by instance,
+and the value of class variable in super class if called by class.
+
+    __PACKAGE__->class_attr('x', default => 0, inherit => 'scalar_copy');
+    __PACKAGE__->class_attr('x', default => sub { [] }, inherit => 'array_copy');
+    __PACKAGE__->class_attr('x', default => sub { {} }, inherit => 'hash_copy');
     
-    my $book = Book->new;
-    $book->title('Good days');
-    
-=head1 OPTIONS
- 
-=head2 default
- 
-Define a default value.
+=head1 STABILITY
 
-    __PACKAGE__->attr('title', default => 'Good news');
-
-If a default value is a reference or object,
-You must wrap the value with sub { }.
-
-    __PACKAGE__->attr('authors', default => sub{ ['Ken', 'Taro'] });
-    __PACKAGE__->attr('ua',      default => sub { LWP::UserAgent->new });
-
-Default value can be written by more simple way.
-
-    __PACKAGE__->attr(title   => 'Good news');
-    __PACKAGE__->attr(authors => sub { ['Ken', 'Taro'] });
-    __PACKAGE__->attr(ua      => sub { LWP::UserAgent->new });
-
-=head2 inherit
-
-Inherit a attribute from a base class's one.
-
-You can inherit a class attribute from base class's one.
-
-    package BaseClass;
-    use base 'Object::Simple';
-    
-    __PACKAGE__->class_attr('cache', default => 30, inherit => 'scalar_copy');
-    
-    package SomeClass;
-    use base 'BaseClass';
-    
-    package main;
-    my $obj = SomeClass->new;
-    $obj->cache; # This is 30, which is inherited from BaseClass's cache.
-
-inherit option must be 'scalar_copy', 'array_copy', 'hash_copy', or sub reference.
-This is used to decide the way to copy the base class attribute.
-
-The following is the implemetations to copy the value.
-
-    'scalar copy' : Normal copy        : sub { return $_[0] }
-    'array_copy'  : Array shallow copy : sub { return [@{$_[0]}] }
-    'hash_copy'   : Hash shallow copy  : sub { return {%{$_[0]}} }
-    sub reference : Your original copy : sub { ... }
-
-If inherit option is specified at dual_attr(), a instance attribute inherit the class attribute.
-
-    package SomeClass;
-    use base 'Object::Simple';
-    
-    __PACKAGE__->dual_attr('filters',
-        default => sub {
-            {
-                trim  => sub { ... },
-                chomp => sub { ... }
-            }
-        },
-        inherit => 'hash_copy'
-    );
-    
-    package main;
-    my $obj = SomeClass->new;
-    $obj->filters; # This is { trim => sub { ... }, chomp => sub { ... } }
-                   # , which is inherit from SomeClass's filters
-
-Good example of inherit options is L<Validator::Custom::HTMLForm>.
-See also this module.
-
-=head1 PROVIDE ONLY ACCESSOR CREATING METHODS
-
-If you want to provide only accessor creating methods, do the following way.
-
-    package YourClass;
-    use base 'LWP::UserAgent';
-    
-    use Object::Simple 'attr';
-    
-    __PACKAGE__->attr('foo');
-
-=head1 SEE ALSO
-
-L<Mojo::Base>, L<Class::Accessor::Fast>
+L<Object::Simple> is stable.
+APIs and the implementation will not be changed from v3.0601.
+Only bug fixing will be done if it is found.
 
 =head1 AUTHOR
  
 Yuki Kimoto, C<< <kimoto.yuki at gmail.com> >>
  
-Github L<http://github.com/yuki-kimoto/>
-
-I develope this module at L<http://github.com/yuki-kimoto/Object-Simple>
-
 =head1 COPYRIGHT & LICENSE
  
 Copyright 2008 Yuki Kimoto, all rights reserved.
